Adds Contexts to Sentry Events
This integration is enabled by default in sentry and adds device, os
and rust contexts to Events, as well as sets a server_name if not
already defined.
See the Contexts Interface documentation for more info.
Examples
use ckb_sentry_contexts as sentry_contexts;
let integration = sentry_contexts::ContextIntegration::new().add_os(false);
let _sentry = sentry::init(sentry::ClientOptions::new().add_integration(integration));Modules
- utils
- Contains functions to retrieve various contexts that can be useful to attach to events
Structs
- Context
Integration - Adds Contexts to Sentry Events.